Camden Roosevelt
Description: Camden Apartments Search
Keywords: Camden, Apartments Search, Apartments For Rent

Back to Results| Start New Search
View Compare List

# Camden Roosevelt (866) 687-5415

Left Right
2101 16th St NW
Washington, DC 20009
Resident Services: (202) 265-4540
Map | Directions
Save To Compare List
M-W, F 10:00AM - 6:00PM
TH 10:00AM - 7:00PM
SA 10:00AM - 5:00PM
SU 1:00PM - 5:00PM
Email us View Office Hours City Blog
Adams Morgan, Dupont Circle, the U Street Corridor and other Washington D.C. hot spots are just steps from your door when you live at Camden Roosevelt. As one of our residents, you will be overwhelmed by the exquisite attention to detail blended with modern amenities in each of our studio, one and two bedroom apartment homes. The renovated historic residences include features like hardwood floors, granite countertops, crown molding and include washers and dryers. Enjoy Wi-Fi access in the resident lounge, work out in our state-of-the-art fitness center or store your favorite vintage in the wine cellar. Other features include a 24-hour concierge service and valet parking garage as well as dry cleaning service. Camden Roosevelt is ideally located in Washington D.C. and the Metro is only blocks away while a Zip Car is right at your doorstep.
Download Community Brochure

- Find an Apartment
- Amenities
- Map / Points of Interest
- What's Up
- Video

## Residence Features

- Private patios & balconies*
- Oversized garden tubs*
- Granite countertops*
- Washer & dryer included
- Built-in bookshelves*
- Studio floor plans available
- Renovated historic apartment homes
- Expanded cable TV package
- Spacious closets
- Crown molding
- Kitchen pantries*
- Linen closets*

## Community Features

- Recycling program
- 24-hour valet parking garage
- 24-hour concierge services
- Expansive 24-hour fitness center with free weights, cardio & rock climbing wall
- Steam room & dry sauna
- Wine cellar
- Executive business center & private conference room
- Valet dry cleaning drop off service
- Access controlled building
- MyCamden.com - online rent payments, maintenance requests & resident social site
- Convenient to Dupont Circle, Adams Morgan & U Street Corridor
- Views of Meridian Hill Park, Washington Monument & the Capitol
- Resident social events
- 24-hour emergency maintenance
- Billiards lounge
- Package receiving
- Close to Washington Central Business District
- Walking distance to the Metro
- Resident lounge & cinema room with Wi-Fi

## Pet Policy

We welcome your cats, with a maximum of two pets per apartment. Sorry, no dogs! See management for pet approval and deposit and fee information.
MyCamden.com
Watch the video now to find out more about our resident exclusive site MyCamden.com!
Watch Video

## What's Nearby

- Schools
- Colleges/Universities
- Grocery Stores
- Shopping Centers
- Restaurants

Get Directions
City Blog

To get a feel for our community, click on the above video link to take a quick tour of our community features, apartment amenities, and to get information on the surrounding area.

## Communities You May Also Like

- Camden Grand Parc Washington, DC $1719 - $8069
- Camden Potomac Yard Arlington, VA $1189 - $3729
- Camden College Park College Park, MD $1229 - $2139
- Camden Summerfield Landover, MD $1259 - $2769
- Camden South Capitol Washington, DC $1459 - $3609
- Camden NoMa Washington, DC $1779 - $4399

Left Right

## Communities Recently Viewed

- Camden Roosevelt Washington, DC $1505 - $4876

Camden Apartment Communities
Arizona, Phoenix Metro
California, Inland Empire
California, LA/Orange County
California, San Diego
Colorado, Denver Metro
Florida, Orlando Metro
Florida, Southeast Florida
Florida, Tampa Metro
Georgia, Atlanta Metro
Maryland, DC Metro
Nevada, Las Vegas Metro
North Carolina, Charlotte Metro
North Carolina, Raleigh Metro
Texas, Austin
Texas, Corpus Christi
Texas, Dallas/Ft. Worth
Texas, Houston Metro
Virginia, DC Metro
Washington DC, DC Metro